@@ -55,16 +55,19 @@ def event_display_interactive(events,
         glyph renders for small values.
     :param log: If true color sclae is used for hitpattern plots.
 
-    Note:
-        How to use:
+    example::
 
-        > st.event_display(context,
-        >                  run_id,
-        >                  time_range=(event['time'],
-        >                              event['endtime'])
-        >                  )
+        from IPython.core.display import display, HTML
+        display(HTML("<style>.container { width:80% !important; }</style>"))
+        import bokeh.plotting as bklt
+        fig = st.event_display_interactive(
+                         run_id,
+                         time_range=(event['time'],
+                                     event['endtime'])
+                         )
+        bklt.show(fig)
 
-    Warning:
+    :raises:
         Raises an error if the user queries a time range which contains
         more than a single event.
 
